@@ -24,7 +24,7 @@ namespace usbguard {
   class DLL_PUBLIC ConfigFile
   {
   public:
-    ConfigFile(const StringVector& known_names);
+    ConfigFile(const StringVector& known_names = StringVector());
     ~ConfigFile();
 
     void open(const String& path);
